# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.http_response import AsyncHttpResponse, HttpResponse
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import parse_obj_as
from .....core.request_options import RequestOptions
from ....commons.errors.entity_conflict_error import EntityConflictError
from ....commons.errors.entity_not_found_error import EntityNotFoundError
from ....commons.errors.unprocessable_entity_error import UnprocessableEntityError
from ....commons.types.encounter_external_id import EncounterExternalId
from ....commons.types.entity_conflict_error_message import EntityConflictErrorMessage
from ....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from ....commons.types.invoice_id import InvoiceId
from ....commons.types.page_token import PageToken
from ....commons.types.patient_external_id import PatientExternalId
from ....commons.types.sort_direction import SortDirection
from ....commons.types.unprocessable_entity_error_message import UnprocessableEntityErrorMessage
from ....invoices.resources.v_2.types.invoice_sort_field import InvoiceSortField
from ....invoices.resources.v_2.types.invoice_status import InvoiceStatus
from .types.create_import_invoice_request import CreateImportInvoiceRequest
from .types.import_invoice import ImportInvoice
from .types.import_invoice_update_request import ImportInvoiceUpdateRequest
from .types.import_invoices_page import ImportInvoicesPage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawV1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def import_invoice(
        self, *, request: CreateImportInvoiceRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ImportInvoice]:
        """
        Import an existing invoice from a third party service to reflect state in Candid.

        Parameters
        ----------
        request : CreateImportInvoiceRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ImportInvoice]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/import-invoice/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ImportInvoice,
                parse_obj_as(
                    type_=ImportInvoice,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityConflictErrorMessage,
                        parse_obj_as(
                            type_=EntityConflictErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_multi(
        self,
        *,
        patient_external_id: typing.Optional[PatientExternalId] = None,
        encounter_external_id: typing.Optional[EncounterExternalId] = None,
        note: typing.Optional[str] = None,
        due_date_before: typing.Optional[dt.date] = None,
        due_date_after: typing.Optional[dt.date] = None,
        status: typing.Optional[typing.Union[InvoiceStatus, typing.Sequence[InvoiceStatus]]] = None,
        limit: typing.Optional[int] = None,
        sort: typing.Optional[InvoiceSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ImportInvoicesPage]:
        """
        Returns all Invoices for the authenticated user's organziation with all filters applied.

        Parameters
        ----------
        patient_external_id : typing.Optional[PatientExternalId]

        encounter_external_id : typing.Optional[EncounterExternalId]

        note : typing.Optional[str]
            partial match supported

        due_date_before : typing.Optional[dt.date]
            all invoices whose due date is before this due date, not inclusive

        due_date_after : typing.Optional[dt.date]
            all invoices whose due date is after this due date, not inclusive

        status : typing.Optional[typing.Union[InvoiceStatus, typing.Sequence[InvoiceStatus]]]
            all invoices that match any of the provided statuses

        limit : typing.Optional[int]
            Defaults to 100

        sort : typing.Optional[InvoiceSortField]
            Defaults to created_at

        sort_direction : typing.Optional[SortDirection]
            Sort direction. Defaults to descending order

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ImportInvoicesPage]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/import-invoice/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "patient_external_id": patient_external_id,
                "encounter_external_id": encounter_external_id,
                "note": note,
                "due_date_before": str(due_date_before) if due_date_before is not None else None,
                "due_date_after": str(due_date_after) if due_date_after is not None else None,
                "status": status,
                "limit": limit,
                "sort": sort,
                "sort_direction": sort_direction,
                "page_token": page_token,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ImportInvoicesPage,
                parse_obj_as(
                    type_=ImportInvoicesPage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, invoice_id: InvoiceId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ImportInvoice]:
        """
        Retrieve and view an import invoice

        Parameters
        ----------
        invoice_id : InvoiceId
            InvoiceId to be returned

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ImportInvoice]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/import-invoice/v1/{jsonable_encoder(invoice_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ImportInvoice,
                parse_obj_as(
                    type_=ImportInvoice,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        invoice_id: InvoiceId,
        *,
        request: ImportInvoiceUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ImportInvoice]:
        """
        Update the information on the imported invoice

        Parameters
        ----------
        invoice_id : InvoiceId

        request : ImportInvoiceUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ImportInvoice]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/import-invoice/v1/{jsonable_encoder(invoice_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ImportInvoice,
                parse_obj_as(
                    type_=ImportInvoice,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def import_invoice(
        self, *, request: CreateImportInvoiceRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ImportInvoice]:
        """
        Import an existing invoice from a third party service to reflect state in Candid.

        Parameters
        ----------
        request : CreateImportInvoiceRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ImportInvoice]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/import-invoice/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ImportInvoice,
                parse_obj_as(
                    type_=ImportInvoice,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityConflictErrorMessage,
                        parse_obj_as(
                            type_=EntityConflictErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_multi(
        self,
        *,
        patient_external_id: typing.Optional[PatientExternalId] = None,
        encounter_external_id: typing.Optional[EncounterExternalId] = None,
        note: typing.Optional[str] = None,
        due_date_before: typing.Optional[dt.date] = None,
        due_date_after: typing.Optional[dt.date] = None,
        status: typing.Optional[typing.Union[InvoiceStatus, typing.Sequence[InvoiceStatus]]] = None,
        limit: typing.Optional[int] = None,
        sort: typing.Optional[InvoiceSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ImportInvoicesPage]:
        """
        Returns all Invoices for the authenticated user's organziation with all filters applied.

        Parameters
        ----------
        patient_external_id : typing.Optional[PatientExternalId]

        encounter_external_id : typing.Optional[EncounterExternalId]

        note : typing.Optional[str]
            partial match supported

        due_date_before : typing.Optional[dt.date]
            all invoices whose due date is before this due date, not inclusive

        due_date_after : typing.Optional[dt.date]
            all invoices whose due date is after this due date, not inclusive

        status : typing.Optional[typing.Union[InvoiceStatus, typing.Sequence[InvoiceStatus]]]
            all invoices that match any of the provided statuses

        limit : typing.Optional[int]
            Defaults to 100

        sort : typing.Optional[InvoiceSortField]
            Defaults to created_at

        sort_direction : typing.Optional[SortDirection]
            Sort direction. Defaults to descending order

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ImportInvoicesPage]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/import-invoice/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "patient_external_id": patient_external_id,
                "encounter_external_id": encounter_external_id,
                "note": note,
                "due_date_before": str(due_date_before) if due_date_before is not None else None,
                "due_date_after": str(due_date_after) if due_date_after is not None else None,
                "status": status,
                "limit": limit,
                "sort": sort,
                "sort_direction": sort_direction,
                "page_token": page_token,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ImportInvoicesPage,
                parse_obj_as(
                    type_=ImportInvoicesPage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, invoice_id: InvoiceId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ImportInvoice]:
        """
        Retrieve and view an import invoice

        Parameters
        ----------
        invoice_id : InvoiceId
            InvoiceId to be returned

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ImportInvoice]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/import-invoice/v1/{jsonable_encoder(invoice_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ImportInvoice,
                parse_obj_as(
                    type_=ImportInvoice,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        invoice_id: InvoiceId,
        *,
        request: ImportInvoiceUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ImportInvoice]:
        """
        Update the information on the imported invoice

        Parameters
        ----------
        invoice_id : InvoiceId

        request : ImportInvoiceUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ImportInvoice]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/import-invoice/v1/{jsonable_encoder(invoice_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ImportInvoice,
                parse_obj_as(
                    type_=ImportInvoice,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
import uuid

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from ....commons.types.date import Date
from ....commons.types.page_token import PageToken
from ....commons.types.regions import Regions
from ....commons.types.sort_direction import SortDirection
from ....commons.types.state import State
from .raw_client import AsyncRawV2Client, RawV2Client
from .types.authorized_signatory import AuthorizedSignatory
from .types.authorized_signatory_update import AuthorizedSignatoryUpdate
from .types.contract_id import ContractId
from .types.contract_sort_field import ContractSortField
from .types.contract_status import ContractStatus
from .types.contract_with_providers import ContractWithProviders
from .types.contracting_provider_id import ContractingProviderId
from .types.contracts_page import ContractsPage
from .types.date_update import DateUpdate
from .types.insurance_types import InsuranceTypes
from .types.regions_update import RegionsUpdate
from .types.rendering_providerid import RenderingProviderid

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V2Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawV2Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawV2Client
        """
        return self._raw_client

    def get(
        self, contract_id: ContractId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ContractWithProviders:
        """
        This API provides access to Professional Contracts. For Professional and Institutional Contracts use Contracts V3.

        Parameters
        ----------
        contract_id : ContractId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ContractWithProviders

        Examples
        --------
        import uuid

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.contracts.v_2.get(
            contract_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._raw_client.get(contract_id, request_options=request_options)
        return _response.data

    def get_multi(
        self,
        *,
        page_token: typing.Optional[PageToken] = None,
        limit: typing.Optional[int] = None,
        contracting_provider_id: typing.Optional[ContractingProviderId] = None,
        rendering_provider_ids: typing.Optional[
            typing.Union[RenderingProviderid, typing.Sequence[RenderingProviderid]]
        ] = None,
        payer_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        states: typing.Optional[typing.Union[State, typing.Sequence[State]]] = None,
        contract_status: typing.Optional[ContractStatus] = None,
        sort: typing.Optional[ContractSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ContractsPage:
        """
        This API provides access to Professional Contracts. For Professional and Institutional Contracts use Contracts V3.

        Parameters
        ----------
        page_token : typing.Optional[PageToken]

        limit : typing.Optional[int]
            Max number of contracts returned. Defaults to 1000. Max is 1000.

        contracting_provider_id : typing.Optional[ContractingProviderId]

        rendering_provider_ids : typing.Optional[typing.Union[RenderingProviderid, typing.Sequence[RenderingProviderid]]]

        payer_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Filter to contracts that include any of the included payer names.

        states : typing.Optional[typing.Union[State, typing.Sequence[State]]]

        contract_status : typing.Optional[ContractStatus]
            The status of the contract. Defaults to `pending`

        sort : typing.Optional[ContractSortField]
            Potentially sort by a contract related attribute.  Defaults to created_at

        sort_direction : typing.Optional[SortDirection]
            Direction of sort, defaulting to desc

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ContractsPage

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.contracts.v_2.get_multi()
        """
        _response = self._raw_client.get_multi(
            page_token=page_token,
            limit=limit,
            contracting_provider_id=contracting_provider_id,
            rendering_provider_ids=rendering_provider_ids,
            payer_names=payer_names,
            states=states,
            contract_status=contract_status,
            sort=sort,
            sort_direction=sort_direction,
            request_options=request_options,
        )
        return _response.data

    def create(
        self,
        *,
        contracting_provider_id: ContractingProviderId,
        rendering_provider_ids: typing.Set[RenderingProviderid],
        payer_uuid: uuid.UUID,
        effective_date: Date,
        regions: Regions,
        commercial_insurance_types: InsuranceTypes,
        medicare_insurance_types: InsuranceTypes,
        medicaid_insurance_types: InsuranceTypes,
        expiration_date: typing.Optional[Date] = OMIT,
        contract_status: typing.Optional[ContractStatus] = OMIT,
        authorized_signatory: typing.Optional[AuthorizedSignatory] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ContractWithProviders:
        """
        Creates a new contract within the user's current organization

        Parameters
        ----------
        contracting_provider_id : ContractingProviderId
            The UUID of the provider under agreement to the contract

        rendering_provider_ids : typing.Set[RenderingProviderid]
            A rendering provider isn't contracted directly with the payer but can render
            services under the contract held by the contracting provider.
            Max items is 4000.

        payer_uuid : uuid.UUID
            The UUID of the insurance company under agreement to the contract

        effective_date : Date
            The starting day upon which the contract is effective

        regions : Regions
            The state(s) to which the contract's coverage extends.
            It may also be set to "national" for the entirety of the US.

        commercial_insurance_types : InsuranceTypes
            The commercial plan insurance types this contract applies.

        medicare_insurance_types : InsuranceTypes
            The Medicare plan insurance types this contract applies.

        medicaid_insurance_types : InsuranceTypes
            The Medicaid plan insurance types this contract applies.

        expiration_date : typing.Optional[Date]
            An optional end day upon which the contract expires

        contract_status : typing.Optional[ContractStatus]

        authorized_signatory : typing.Optional[AuthorizedSignatory]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ContractWithProviders

        Examples
        --------
        import uuid

        from candid import CandidApiClient
        from candid.resources.commons import Regions_States, State
        from candid.resources.contracts.resources.v_2 import InsuranceTypes

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.contracts.v_2.create(
            contracting_provider_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            rendering_provider_ids=[
                uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                )
            ],
            payer_uuid=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            effective_date="effective_date",
            regions=Regions_States(
                states=[State.AA, State.AA],
            ),
            commercial_insurance_types=InsuranceTypes(),
            medicare_insurance_types=InsuranceTypes(),
            medicaid_insurance_types=InsuranceTypes(),
        )
        """
        _response = self._raw_client.create(
            contracting_provider_id=contracting_provider_id,
            rendering_provider_ids=rendering_provider_ids,
            payer_uuid=payer_uuid,
            effective_date=effective_date,
            regions=regions,
            commercial_insurance_types=commercial_insurance_types,
            medicare_insurance_types=medicare_insurance_types,
            medicaid_insurance_types=medicaid_insurance_types,
            expiration_date=expiration_date,
            contract_status=contract_status,
            authorized_signatory=authorized_signatory,
            request_options=request_options,
        )
        return _response.data

    def delete(self, contract_id: ContractId, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Parameters
        ----------
        contract_id : ContractId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import uuid

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.contracts.v_2.delete(
            contract_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._raw_client.delete(contract_id, request_options=request_options)
        return _response.data

    def update(
        self,
        contract_id: ContractId,
        *,
        rendering_provider_ids: typing.Optional[typing.Set[RenderingProviderid]] = OMIT,
        effective_date: typing.Optional[Date] = OMIT,
        expiration_date: typing.Optional[DateUpdate] = OMIT,
        regions: typing.Optional[RegionsUpdate] = OMIT,
        contract_status: typing.Optional[ContractStatus] = OMIT,
        authorized_signatory: typing.Optional[AuthorizedSignatoryUpdate] = OMIT,
        commercial_insurance_types: typing.Optional[InsuranceTypes] = OMIT,
        medicare_insurance_types: typing.Optional[InsuranceTypes] = OMIT,
        medicaid_insurance_types: typing.Optional[InsuranceTypes] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ContractWithProviders:
        """
        Parameters
        ----------
        contract_id : ContractId

        rendering_provider_ids : typing.Optional[typing.Set[RenderingProviderid]]
            A rendering provider isn't contracted directly with the payer but can render
            services under the contract held by the contracting provider.
            Max items is 4000.

        effective_date : typing.Optional[Date]
            The starting day upon which the contract is effective

        expiration_date : typing.Optional[DateUpdate]
            An optional end day upon which the contract expires

        regions : typing.Optional[RegionsUpdate]
            If present, the contract's rendering providers will be patched to this exact
            value, overriding what was set before.

        contract_status : typing.Optional[ContractStatus]

        authorized_signatory : typing.Optional[AuthorizedSignatoryUpdate]

        commercial_insurance_types : typing.Optional[InsuranceTypes]

        medicare_insurance_types : typing.Optional[InsuranceTypes]

        medicaid_insurance_types : typing.Optional[InsuranceTypes]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ContractWithProviders

        Examples
        --------
        import uuid

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.contracts.v_2.update(
            contract_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._raw_client.update(
            contract_id,
            rendering_provider_ids=rendering_provider_ids,
            effective_date=effective_date,
            expiration_date=expiration_date,
            regions=regions,
            contract_status=contract_status,
            authorized_signatory=authorized_signatory,
            commercial_insurance_types=commercial_insurance_types,
            medicare_insurance_types=medicare_insurance_types,
            medicaid_insurance_types=medicaid_insurance_types,
            request_options=request_options,
        )
        return _response.data


class AsyncV2Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawV2Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawV2Client
        """
        return self._raw_client

    async def get(
        self, contract_id: ContractId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ContractWithProviders:
        """
        This API provides access to Professional Contracts. For Professional and Institutional Contracts use Contracts V3.

        Parameters
        ----------
        contract_id : ContractId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ContractWithProviders

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.contracts.v_2.get(
                contract_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(contract_id, request_options=request_options)
        return _response.data

    async def get_multi(
        self,
        *,
        page_token: typing.Optional[PageToken] = None,
        limit: typing.Optional[int] = None,
        contracting_provider_id: typing.Optional[ContractingProviderId] = None,
        rendering_provider_ids: typing.Optional[
            typing.Union[RenderingProviderid, typing.Sequence[RenderingProviderid]]
        ] = None,
        payer_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        states: typing.Optional[typing.Union[State, typing.Sequence[State]]] = None,
        contract_status: typing.Optional[ContractStatus] = None,
        sort: typing.Optional[ContractSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ContractsPage:
        """
        This API provides access to Professional Contracts. For Professional and Institutional Contracts use Contracts V3.

        Parameters
        ----------
        page_token : typing.Optional[PageToken]

        limit : typing.Optional[int]
            Max number of contracts returned. Defaults to 1000. Max is 1000.

        contracting_provider_id : typing.Optional[ContractingProviderId]

        rendering_provider_ids : typing.Optional[typing.Union[RenderingProviderid, typing.Sequence[RenderingProviderid]]]

        payer_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Filter to contracts that include any of the included payer names.

        states : typing.Optional[typing.Union[State, typing.Sequence[State]]]

        contract_status : typing.Optional[ContractStatus]
            The status of the contract. Defaults to `pending`

        sort : typing.Optional[ContractSortField]
            Potentially sort by a contract related attribute.  Defaults to created_at

        sort_direction : typing.Optional[SortDirection]
            Direction of sort, defaulting to desc

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ContractsPage

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.contracts.v_2.get_multi()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_multi(
            page_token=page_token,
            limit=limit,
            contracting_provider_id=contracting_provider_id,
            rendering_provider_ids=rendering_provider_ids,
            payer_names=payer_names,
            states=states,
            contract_status=contract_status,
            sort=sort,
            sort_direction=sort_direction,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self,
        *,
        contracting_provider_id: ContractingProviderId,
        rendering_provider_ids: typing.Set[RenderingProviderid],
        payer_uuid: uuid.UUID,
        effective_date: Date,
        regions: Regions,
        commercial_insurance_types: InsuranceTypes,
        medicare_insurance_types: InsuranceTypes,
        medicaid_insurance_types: InsuranceTypes,
        expiration_date: typing.Optional[Date] = OMIT,
        contract_status: typing.Optional[ContractStatus] = OMIT,
        authorized_signatory: typing.Optional[AuthorizedSignatory] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ContractWithProviders:
        """
        Creates a new contract within the user's current organization

        Parameters
        ----------
        contracting_provider_id : ContractingProviderId
            The UUID of the provider under agreement to the contract

        rendering_provider_ids : typing.Set[RenderingProviderid]
            A rendering provider isn't contracted directly with the payer but can render
            services under the contract held by the contracting provider.
            Max items is 4000.

        payer_uuid : uuid.UUID
            The UUID of the insurance company under agreement to the contract

        effective_date : Date
            The starting day upon which the contract is effective

        regions : Regions
            The state(s) to which the contract's coverage extends.
            It may also be set to "national" for the entirety of the US.

        commercial_insurance_types : InsuranceTypes
            The commercial plan insurance types this contract applies.

        medicare_insurance_types : InsuranceTypes
            The Medicare plan insurance types this contract applies.

        medicaid_insurance_types : InsuranceTypes
            The Medicaid plan insurance types this contract applies.

        expiration_date : typing.Optional[Date]
            An optional end day upon which the contract expires

        contract_status : typing.Optional[ContractStatus]

        authorized_signatory : typing.Optional[AuthorizedSignatory]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ContractWithProviders

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient
        from candid.resources.commons import Regions_States, State
        from candid.resources.contracts.resources.v_2 import InsuranceTypes

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.contracts.v_2.create(
                contracting_provider_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                rendering_provider_ids=[
                    uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    )
                ],
                payer_uuid=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                effective_date="effective_date",
                regions=Regions_States(
                    states=[State.AA, State.AA],
                ),
                commercial_insurance_types=InsuranceTypes(),
                medicare_insurance_types=InsuranceTypes(),
                medicaid_insurance_types=InsuranceTypes(),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            contracting_provider_id=contracting_provider_id,
            rendering_provider_ids=rendering_provider_ids,
            payer_uuid=payer_uuid,
            effective_date=effective_date,
            regions=regions,
            commercial_insurance_types=commercial_insurance_types,
            medicare_insurance_types=medicare_insurance_types,
            medicaid_insurance_types=medicaid_insurance_types,
            expiration_date=expiration_date,
            contract_status=contract_status,
            authorized_signatory=authorized_signatory,
            request_options=request_options,
        )
        return _response.data

    async def delete(self, contract_id: ContractId, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Parameters
        ----------
        contract_id : ContractId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.contracts.v_2.delete(
                contract_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(contract_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        contract_id: ContractId,
        *,
        rendering_provider_ids: typing.Optional[typing.Set[RenderingProviderid]] = OMIT,
        effective_date: typing.Optional[Date] = OMIT,
        expiration_date: typing.Optional[DateUpdate] = OMIT,
        regions: typing.Optional[RegionsUpdate] = OMIT,
        contract_status: typing.Optional[ContractStatus] = OMIT,
        authorized_signatory: typing.Optional[AuthorizedSignatoryUpdate] = OMIT,
        commercial_insurance_types: typing.Optional[InsuranceTypes] = OMIT,
        medicare_insurance_types: typing.Optional[InsuranceTypes] = OMIT,
        medicaid_insurance_types: typing.Optional[InsuranceTypes] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ContractWithProviders:
        """
        Parameters
        ----------
        contract_id : ContractId

        rendering_provider_ids : typing.Optional[typing.Set[RenderingProviderid]]
            A rendering provider isn't contracted directly with the payer but can render
            services under the contract held by the contracting provider.
            Max items is 4000.

        effective_date : typing.Optional[Date]
            The starting day upon which the contract is effective

        expiration_date : typing.Optional[DateUpdate]
            An optional end day upon which the contract expires

        regions : typing.Optional[RegionsUpdate]
            If present, the contract's rendering providers will be patched to this exact
            value, overriding what was set before.

        contract_status : typing.Optional[ContractStatus]

        authorized_signatory : typing.Optional[AuthorizedSignatoryUpdate]

        commercial_insurance_types : typing.Optional[InsuranceTypes]

        medicare_insurance_types : typing.Optional[InsuranceTypes]

        medicaid_insurance_types : typing.Optional[InsuranceTypes]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ContractWithProviders

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.contracts.v_2.update(
                contract_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            contract_id,
            rendering_provider_ids=rendering_provider_ids,
            effective_date=effective_date,
            expiration_date=expiration_date,
            regions=regions,
            contract_status=contract_status,
            authorized_signatory=authorized_signatory,
            commercial_insurance_types=commercial_insurance_types,
            medicare_insurance_types=medicare_insurance_types,
            medicaid_insurance_types=medicaid_insurance_types,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from ....core import enum

T_Result = typing.TypeVar("T_Result")


class NextResponsibleParty(enum.StrEnum):
    PRIMARY = "primary"
    SECONDARY = "secondary"
    TERTIARY = "tertiary"
    PATIENT = "patient"
    NON_INSURANCE = "non_insurance"
    NONE = "none"
    _UNKNOWN = "__NEXTRESPONSIBLEPARTY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "NextResponsibleParty":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        primary: typing.Callable[[], T_Result],
        secondary: typing.Callable[[], T_Result],
        tertiary: typing.Callable[[], T_Result],
        patient: typing.Callable[[], T_Result],
        non_insurance: typing.Callable[[], T_Result],
        none: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is NextResponsibleParty.PRIMARY:
            return primary()
        if self is NextResponsibleParty.SECONDARY:
            return secondary()
        if self is NextResponsibleParty.TERTIARY:
            return tertiary()
        if self is NextResponsibleParty.PATIENT:
            return patient()
        if self is NextResponsibleParty.NON_INSURANCE:
            return non_insurance()
        if self is NextResponsibleParty.NONE:
            return none()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class DimensionName(enum.StrEnum):
    """
    The name of a dimension.
    """

    PAYER_UUID = "payer_uuid"
    ORGANIZATION_BILLING_PROVIDER_ID = "organization_billing_provider_id"
    CPT_CODE = "cpt_code"
    _UNKNOWN = "__DIMENSIONNAME_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "DimensionName":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        payer_uuid: typing.Callable[[], T_Result],
        organization_billing_provider_id: typing.Callable[[], T_Result],
        cpt_code: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is DimensionName.PAYER_UUID:
            return payer_uuid()
        if self is DimensionName.ORGANIZATION_BILLING_PROVIDER_ID:
            return organization_billing_provider_id()
        if self is DimensionName.CPT_CODE:
            return cpt_code()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AuthZeroMetadata(UniversalBaseModel):
    """
    Examples
    --------
    from candid.resources.users.resources.v_2 import AuthZeroMetadata

    AuthZeroMetadata(
        auth_0_id="auth0|5f9b3b5a7b0b0d006a2b0b0b",
    )
    """

    auth_0_id: str = pydantic.Field(alias="auth0_id")

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class EncounterSubmissionExpectation(enum.StrEnum):
    """
    Used to describe the currently expected target form for this encounter.  This effects what
    validations and queues the form is processed under.  Before submission,
    this value will be required by some rules or user intervention.  It can be changed
    at any time, although doing so may incur other rules.
    """

    TARGET_PROFESSIONAL = "TARGET_PROFESSIONAL"
    """
    Treat this encounter as a potential professional claim submission and validate it as such.
    """

    TARGET_INSTITUTIONAL = "TARGET_INSTITUTIONAL"
    """
    Treat this encounter as a potential institutional claim submission and validate it as such.
    """

    _UNKNOWN = "__ENCOUNTERSUBMISSIONEXPECTATION_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "EncounterSubmissionExpectation":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        target_professional: typing.Callable[[], T_Result],
        target_institutional: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is EncounterSubmissionExpectation.TARGET_PROFESSIONAL:
            return target_professional()
        if self is EncounterSubmissionExpectation.TARGET_INSTITUTIONAL:
            return target_institutional()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class ConditionCode(enum.StrEnum):
    """

    FL 18-28 - Condition Codes
    Source: UB-04 Manual 2025, Pages 64-81 (FL18-28, Pages 1-18)
    Excludes codes designated as "Payer Codes" or "FOR PUBLIC HEALTH DATA REPORTING ONLY"
    unless usage on claims is indicated.

    """

    C_01 = "01"
    """
    MILITARY SERVICE RELATED - Medical condition incurred during military service.
    """

    C_02 = "02"
    """
    CONDITION IS EMPLOYMENT RELATED - Patient alleges that medical condition is due to environment/events resulting from employment.
    """

    C_03 = "03"
    """
    PATIENT COVERED BY INSURANCE NOT REFLECTED HERE - Indicates that patient/patient representative has stated that coverage may exist beyond that reflected on this bill.
    """

    C_04 = "04"
    """
    INFORMATION ONLY BILL - Indicates submission of bill is for informational purposes only. Examples would include a bill submitted as a utilization report, or a bill for a beneficiary who enrolled in a risk-based managed care plan and the hospital expects to receive payment from the plan.
    """

    C_05 = "05"
    """
    LIEN HAS BEEN FILED - Provider has filed legal claim for recovery of funds potentially due a patient resulting from legal action initiated by or on behalf of the patient.
    """

    C_06 = "06"
    """
    ESRD PATIENT IN FIRST 30 MONTHS OF ENTITLEMENT COVERED BY EMPLOYER GROUP HEALTH INSURANCE - Code indicates Medicare as the secondary insurer because the patient also is covered through an employer group health insurance during his first 30 months of End Stage Renal Disease (ESRD) entitlement.
    """

    C_07 = "07"
    """
    TREATMENT OF NON-TERMINAL CONDITION FOR HOSPICE PATIENT - Code indicates the patient is a hospice enrollee, but the provider is not treating his terminal condition and is therefore, requesting regular Medicare reimbursement.
    """

    C_08 = "08"
    """
    BENEFICIARY WOULD NOT PROVIDE INFORMATION CONCERNING OTHER INSURANCE COVERAGE - Enter this code if the beneficiary would not provide information concerning other insurance coverage.
    """

    C_09 = "09"
    """
    NEITHER PATIENT NOR SPOUSE IS EMPLOYED - Indicates that in response to development questions, the patient and spouse (if the patient is married) have denied any employment.
    """

    C_10 = "10"
    """
    PATIENT AND/OR SPOUSE IS EMPLOYED BUT NO EGHP EXISTS - Code indicates that in response to development questions, the patient and/or spouse have indicated that one is or both are employed but have no group health insurance from an EGHP or other employer sponsored or provided health insurance that covers the patient.
    """

    C_11 = "11"
    """
    DISABLED BENEFICIARY BUT NO LGHP - Code indicates that in response to development questions, the disabled beneficiary and/or family members have indicated that one is or more are employed but have no group health insurance from an LGHP or other employer sponsored or provided health insurance that covers the patient.
    """

    C_17 = "17"
    """
    PATIENT IS HOMELESS - The patient is homeless.
    """

    C_18 = "18"
    """
    MAIDEN NAME RETAINED - A dependent spouse entitled to benefits who does not use her husband's last name.
    """

    C_19 = "19"
    """
    CHILD RETAINS MOTHER'S NAME - A patient who is a dependent child entitled to benefits and does not have its father's last name.
    """

    C_20 = "20"
    """
    BENEFICIARY REQUESTED BILLING - Provider realizes services are non-covered level of care or excluded, but beneficiary requests determination by payer. (Currently limited to home health and inpatient SNF claims.)
    """

    C_21 = "21"
    """
    BILLING FOR DENIAL NOTICE - Provider realizes services are non-covered level of care or excluded, but requests notice from Medicare or other payer.
    """

    C_22 = "22"
    """
    PATIENT ON MULTIPLE DRUG REGIMEN - A patient who is receiving multiple intravenous drugs while on home IV therapy.
    """

    C_23 = "23"
    """
    HOME CARE GIVER AVAILABLE - The patient has a caregiver available to assist him or her during self-administration of an intravenous drug.
    """

    C_24 = "24"
    """
    HOME IV PATIENT ALSO RECEIVING HHA SERVICES - The patient is under the care of Home Health Agency while receiving home IV drug therapy services.
    """

    C_25 = "25"
    """
    PATIENT IS NON-U.S. RESIDENT - The patient is not a resident of the United States.
    """

    C_26 = "26"
    """
    VA ELIGIBLE PATIENT CHOOSES TO RECEIVE SERVICES IN A MEDICARE CERTIFIED FACILITY - Indicates that the patient is a VA eligible patient and chooses to receive services in a Medicare certified provider instead of a VA facility.
    """

    C_27 = "27"
    """
    PATIENT REFERRED TO A SOLE COMMUNITY HOSPITAL FOR A DIAGNOSTIC LABORATORY TEST - To be reported by Sole Community hospitals only. Report this code to indicate the patient was referred for a diagnostic laboratory test. Do not report this code when a specimen only is referred.
    """

    C_28 = "28"
    """
    PATIENT AND/OR SPOUSE’S EGHP IS SECONDARY TO MEDICARE - Code indicates that in response to development questions, the patient and/or spouse have indicated that one is or both are employed and that there is group health insurance from an EGHP or other employer sponsored or provided health insurance that covers the patient but that either: (1) the EGHP is a single employer plan and the employer has fewer than 20 full and part-time employees; or, (2) the EGHP is a multi or multiple employer plan that elects to pay secondary to Medicare for employees and spouses aged 65 and older for those participating employers who have fewer than 20 employees.
    """

    C_29 = "29"
    """
    DISABLED BENEFICIARY AND/OR FAMILY MEMBER’S LGHP IS SECONDARY TO MEDICARE - Code indicates that in response to development questions, the patient and/or family member(s) have indicated that one is or more are employed. There also is group health insurance coverage from a LGHP or other employer sponsored or provided health insurance that covers the patient. Generally, (1) the LGHP is a single employer plan and that the employer has fewer than 100 full and part-time employees; or, (2), the LGHP is a multiple employer plan and that all employers participating in the plan have fewer than 100 full and part-time employees.
    """

    C_30 = "30"
    """
    QUALIFYING CLINICAL TRIALS - Non-research services provided to patients enrolled in a Qualified Clinical Trial.
    """

    C_31 = "31"
    """
    PATIENT IS STUDENT (FULL TIME - DAY) - Patient declares that he or she is enrolled as a full time day student.
    """

    C_32 = "32"
    """
    PATIENT IS STUDENT (COOPERATIVE/ WORK STUDY PROGRAM) - Self-explanatory.
    """

    C_33 = "33"
    """
    PATIENT IS STUDENT (FULL TIME - NIGHT) - Patient declares that he or she is enrolled as a full time night student.
    """

    C_34 = "34"
    """
    PATIENT IS STUDENT (PART TIME) - Patient declares that he or she is enrolled as a part time student.
    """

    C_35 = "35"
    """
    PACE ELIGIBLE PATIENT DISENROLLS DURING AN INPATIENT ADMISSION - Indicates that the patient is a PACE eligible patient that has disenrolled from PACE during an inpatient admission.
    """

    C_36 = "36"
    """
    GENERAL CARE PATIENT IN A SPECIAL UNIT - Patient temporarily placed in special care unit bed because no general care beds available.
    """

    C_37 = "37"
    """
    WARD ACCOMMODATION AT PATIENT REQUEST - Patient assigned to ward accommodations at patient’s request.
    """

    C_38 = "38"
    """
    SEMI-PRIVATE ROOM NOT AVAILABLE - Indicates that either private or ward accommodations were assigned because semi- private accommodations were not available.
    """

    C_39 = "39"
    """
    PRIVATE ROOM MEDICALLY NECESSARY - Patient needs a private room for medical requirements.
    """

    C_40 = "40"
    """
    SAME DAY TRANSFER - Patient transferred to another facility before midnight on the day of admission.
    """

    C_41 = "41"
    """
    PARTIAL HOSPITALIZATION - Indicates claim is for partial hospitalization services.
    """

    C_42 = "42"
    """
    CONTINUING CARE NOT RELATED TO INPATIENT HOSPITALIZATION - Continuing care not related to the condition or diagnosis for which the individual received inpatient hospital services.
    """

    C_43 = "43"
    """
    CONTINUING CARE NOT PROVIDED WITHIN PRESCRIBED POST-DISCHARGE WINDOW - Continuing care related to the inpatient admission but the prescribed care was not provided within the post-discharge window.
    """

    C_44 = "44"
    """
    INPATIENT ADMISSION CHANGED TO OUTPATIENT - For use on outpatient claims only, when the physician ordered inpatient services, but upon internal utilization review performed before the claim was originally submitted, the hospital determined that the services did not meet its inpatient criteria. (Note: For Medicare, the change in patient status from inpatient to outpatient is made prior to discharge or release, while the beneficiary is still a patient of the hospital.)
    """

    C_45 = "45"
    """
    GENDER INCONGRUENCE - Characterized by a marked and persistent incongruence between an individual's experienced gender and the sex at birth.
    """

    C_46 = "46"
    """
    NON-AVAILABILITY STATEMENT ON FILE - A non-availability statement must be issued for each TRICARE claim for non-emergency inpatient care when the TRICARE beneficiary resides within the catchment’s area (usually a 40-mile radius) of a Uniformed Services Hospital.
    """

    C_47 = "47"
    """
    TRANSFER FROM ANOTHER HOME HEALTH AGENCY (EFFECTIVE 7/1/10) - The patient was admitted to this home health agency as a transfer from another home health agency.
    """

    C_48 = "48"
    """
    PSYCHIATRIC RESIDENTIAL TREATMENT CENTERS FOR CHILDREN AND ADOLESCENTS (RTCS) - Code to identify claims submitted by a “TRICARE - authorized” psychiatric Residential Treatment Center (RTC) for Children and Adolescents.
    """

    C_49 = "49"
    """
    PRODUCT REPLACEMENT WITHIN PRODUCT LIFECYCLE (EFFECTIVE 1/1/15) - Replacement of a product earlier than the anticipated lifecycle.
    """

    C_50 = "50"
    """
    PRODUCT REPLACEMENT FOR KNOWN RECALL OF A PRODUCT - Manufacturer or FDA has identified the product for recall and therefore replacement.
    """

    C_51 = "51"
    """
    ATTESTATION OF UNRELATED OUTPATIENT NONDIAGNOSTIC SERVICES (EFFECTIVE 4/1/11) - The hospital attests that the outpatient nondiagnostic service provided within 3 calendars days (1 calendar day for non-subsection (d) hospitals) prior to the admission is not related to the admission to the inpatient stay. For use on outpatient claims only.
    """

    C_52 = "52"
    """
    OUT OF HOSPICE SERVICE AREA (EFFECTIVE 7/1/12) - Code used when the patient is discharged for moving out of the hospice service area, including patients admitted to a hospital without contractual arrangements with the hospice.
    """

    C_53 = "53"
    """
    INITIAL PLACEMENT OF A MEDICAL DEVICE PROVIDED AS PART OF A CLINICAL TRIAL OR A FREE SAMPLE. (EFFECTIVE 7/1/15) - Code is for outpatient claims that have received a device credit upon initial medical device placement in a clinical trial or a free sample.
    """

    C_54 = "54"
    """
    NO SKILLED HOME HEALTH VISITS IN BILLING PERIOD. POLICY EXCEPTION DOCUMENTED AT THE HOME HEALTH AGENCY (EFFECTIVE 7/1/16) - Report when the Home Health claim is submitted without any skilled visits due to a circumstance that is allowed by the payer and indicate that the policy exception is documented at the Home Health Agency.
    """

    C_55 = "55"
    """
    SNF BED NOT AVAILABLE - Code indicates the patient’s SNF admission was delayed more than 30 days after hospital discharge because a SNF bed was not available.
    """

    C_56 = "56"
    """
    MEDICAL APPROPRIATENESS - Code indicates the patient’s SNF admission was delayed more than 30 days after hospital discharge because his condition made it inappropriate to begin active care within that period.
    """

    C_57 = "57"
    """
    SNF READMISSION - Code indicates the patient was previously receiving Medicare covered SNF care within 30 days of this readmission.
    """

    C_58 = "58"
    """
    TERMINATED MEDICARE ADVANTAGE ENROLLEE - Code indicates that patient is a terminated enrollee in a Medicare Advantage plan whose three-day inpatient hospital stay was waived.
    """

    C_59 = "59"
    """
    NON-PRIMARY ESRD FACILITY - Code indicates that ESRD beneficiary received non- scheduled or emergency dialysis services at a facility other than his/her primary ESRD dialysis facility.
    """

    C_60 = "60"
    """
    DAY OUTLIER - A hospital being paid under a prospective payment system is reporting this stay as a day outlier.
    """

    C_61 = "61"
    """
    COST OUTLIER - A hospital being paid under a prospective payment system is requesting additional payment for this stay as a cost outlier.
    """

    C_66 = "66"
    """
    PROVIDER DOES NOT WISH COST OUTLIER PAYMENT - A hospital paid under a prospective payment system is NOT requesting additional payment for this stay as a cost outlier.
    """

    C_67 = "67"
    """
    BENEFICIARY ELECTS NOT TO USE LIFE TIME RESERVE (LTR) DAYS - Indicates beneficiary elects not to use LTR days.
    """

    C_68 = "68"
    """
    BENEFICIARY ELECTS TO USE LIFE TIME RESERVE (LTR) DAYS - Indicates beneficiary has elected to use LTR days when charges are less than LTR co-insurance amounts.
    """

    C_69 = "69"
    """
    IME/DGME/N&AH PAYMENT ONLY - Code indicates a request for a supplemental payment for IME/DGME/N&AH (Indirect Medical Education/Graduate Medical Education/ Nursing and Allied Health).
    """

    C_70 = "70"
    """
    SELF-ADMINISTERED ANEMIA MANAGEMENT DRUG - Code indicates the billing is for a home dialysis patient who self administers an anemia management drug, such as erythropoietin alpha (EPO) or darbepoetin alpha.
    """

    C_71 = "71"
    """
    FULL CARE IN UNIT - Code indicates the billing is for a patient who received staff-assisted dialysis services in a hospital or renal dialysis facility.
    """

    C_72 = "72"
    """
    SELF CARE IN UNIT - Code indicates the billing is for a patient who managed his own dialysis services without staff assistance in a hospital or renal dialysis facility.
    """

    C_73 = "73"
    """
    ESRD SELF CARE TRAINING - Code indicates the billing is for special dialysis services training when a patient or caregiver is learning to perform dialysis.
    """

    C_74 = "74"
    """
    HOME - Code indicates the billing is for a patient who received dialysis services at home, but where code 75 below does not apply.
    """

    C_75 = "75"
    """
    HOME - 100 PERCENT REIMBURSEMENT - Code indicates the billing is for a patient who received dialysis services at home, using a dialysis machine that was purchased by Medicare under the 100 percent program.
    """

    C_76 = "76"
    """
    BACK-UP IN FACILITY DIALYSIS - Code indicates the billing is for a home dialysis patient who received back-up dialysis in a facility.
    """

    C_77 = "77"
    """
    PROVIDER ACCEPTS OR IS OBLIGATED/REQUIRED DUE TO A CONTRACTUAL ARRANGEMENT OR LAW TO ACCEPT PAYMENT BY A PRIMARY PAYER AS PAYMENT IN FULL. - Code indicates you have accepted or are
    obligated/required due to a contractual
    arrangement or law to accept payment as
    payment in full. Therefore, no payment is due.
    """

    C_78 = "78"
    """
    NEW COVERAGE NOT IMPLEMENTED BY MANAGED CARE PLAN - Billing is for a newly covered service for which
    the managed care plan/HMO does not pay. (Note:
    For outpatient bills Condition Code 04 should be
    omitted).
    """

    C_79 = "79"
    """
    CORF SERVICES PROVIDED OFFSITE - Enter this code to indicate that physical therapy,
    occupational therapy, or speech pathology ser-
    vices were provided offsite.
    """

    C_80 = "80"
    """
    HOME DIALYSIS - NURSING FACILITY - Home dialysis furnished in a SNF or nursing facility.
    """

    C_81 = "81"
    """
    C-SECTIONS/INDUCTIONS < 39 WEEKS - MEDICAL NECESSITY - C-sections or inductions performed at less than 39 weeks gestation for medical necessity.
    """

    C_82 = "82"
    """
    C-SECTIONS/INDUCTIONS < 39 WEEKS - ELECTIVE - C-sections or inductions performed at less than 39 weeks gestation electively.
    """

    C_83 = "83"
    """
    C-SECTIONS/INDUCTIONS 39 WEEKS OR GREATER - C-sections or inductions performed at 39 weeks gestation or greater.
    """

    C_84 = "84"
    """
    DIALYSIS FOR ACUTE KIDNEY INJURY (AKI) (EFFECTIVE 1/1/17) - Dialysis facilities (Type of Bill 072x) enter this code to indicate that the billing is for a patient with AKI. (Not to be used for patients with End Stage Renal Disease)
    """

    C_85 = "85"
    """
    DELAYED RECERTIFICATION OF HOSPICE TERMINAL ILLNESS (EFFECTIVE 1/1/17) - Used when hospice recertification is untimely.
    """

    C_86 = "86"
    """
    ADDITIONAL HEMODIALYSIS TREATMENTS WITH MEDICAL JUSTIFICATION (ORIGINAL EFFECTIVE DATE DELAYED. NEW EFFECTIVE DATE TBD*) - Enter this code to indicate that the billing is for a patient receiving hemodialysis who exhibits a medical condition that necessitates hemodialysis at a frequency greater than the patient’s plan of care and all treatments on the claim are reasonable and necessary.
    """

    C_87 = "87"
    """
    ESRD SELF CARE RETRAINING (EFFECTIVE 7/1/17) - Code indicates the billing is for special dialysis services retraining where the patient or caregiver has previously completed dialysis training.
    """

    C_88 = "88"
    """
    ALLOGENEIC STEM CELL TRANSPLANT RELATED DONOR CHARGES (EFFECTIVE 7/1/20) - Claim submitted is solely for separately billed charges for evaluating related stem cell transplant donor candidates prior to the actual transplant claim.
    """

    C_89 = "89"
    """
    OPIOID TREATMENT PROGRAM (EFFECTIVE 1/1/21) - Indicates claim is for opioid treatment program services.
    """

    C_90 = "90"
    """
    EXPANDED ACCESS APPROVAL (EFFECTIVE 2/1/21) - Service provided as part of an Expanded Access approval.
    """

    C_91 = "91"
    """
    EMERGENCY USE AUTHORIZATION (EFFECTIVE 2/1/21) - Service provided as part of an Emergency Use Authorization.
    """

    C_92 = "92"
    """
    INTENSIVE OUTPATIENT PROGRAM (IOP) (EFFECTIVE FOR SERVICES FURNISHED ON OR AFTER 1/1/2024) - Code indicates claim is for Intensive Outpatient Services
    """

    CA_0 = "A0"
    """
    TRICARE EXTERNAL PARTNERSHIP PROGRAM - This code identifies TRICARE claims submitted under the External Partnership Program.
    """

    CA_1 = "A1"
    """
    BIRTH DATE - INSURED A - The birth date of the individual in whose name the insurance is carried.
    """

    CA_2 = "A2"
    """
    PHYSICALLY HANDICAPPED CHILDREN’S PROGRAM - Services provided under this program receive special funding through Title VII of the Social Security Act or the TRICARE program for the Handicapped.
    """

    CA_3 = "A3"
    """
    SPECIAL FEDERAL FUNDING - This code has been designed for uniform use as defined by state law.
    """

    CA_4 = "A4"
    """
    FAMILY PLANNING - This code has been designed for uniform use as defined by state law.
    """

    CA_5 = "A5"
    """
    DISABILITY - This code has been designed for uniform use as defined by state law.
    """

    CA_6 = "A6"
    """
    VACCINES/MEDICARE 100% PAYMENT - This code identifies that pneumococcal pneumonia and influenza vaccine services are reimbursed under special Medicare program provisions and Medicare deductible and coinsurance requirements do not apply.
    """

    CA_7 = "A7"
    """
    HOSPITAL SERVICES PROVIDED IN A MOBILE FACILITY OR WITH PORTABLE UNITS (EFFECTIVE 4/1/20). - Code indicates that hospital services were provided in a mobile facility or with portable units.
    """

    CA_9 = "A9"
    """
    SECOND OPINION SURGERY - Services requested to support second opinion on surgery.
    """

    CAA = "AA"
    """
    ABORTION PERFORMED DUE TO RAPE - Code indicates abortion performed due to a rape.
    """

    CAB = "AB"
    """
    ABORTION PERFORMED DUE TO INCEST - Code indicates abortion performed due to an incident of incest.
    """

    CAC = "AC"
    """
    ABORTION PERFORMED DUE TO SERIOUS FETAL GENETIC DEFECT, DEFORMITY, OR ABNORMALITY - Code indicates abortion performed due to a genetic defect, a deformity, or abnormality to the fetus.
    """

    CAD = "AD"
    """
    ABORTION PERFORMED DUE TO A LIFE ENDANGERING PHYSICAL CONDITION - Abortion performed due to a life endangering physical condition caused by, or, arising from or exacerbated by the pregnancy itself.
    """

    CAE = "AE"
    """
    ABORTION PERFORMED DUE TO PHYSICAL HEALTH OF MOTHER THAT IS NOT LIFE ENDANGERING - Abortion performed due to physical health of mother that is not life endangering.
    """

    CAF = "AF"
    """
    ABORTION PERFORMED DUE TO EMOTIONAL/PSYCHOLOGICAL HEALTH OF THE MOTHER - Abortion performed due to emotional psychological health of the mother.
    """

    CAG = "AG"
    """
    ABORTION PERFORMED DUE TO SOCIAL OR ECONOMIC REASONS - Abortion performed due to social or economic reasons.
    """

    CAH = "AH"
    """
    ELECTIVE ABORTION - Elective abortion.
    """

    CAI = "AI"
    """
    STERILIZATION - Sterilization.
    """

    CAJ = "AJ"
    """
    PAYER RESPONSIBLE FOR CO-PAYMENT - Payer responsible for co-payment.
    """

    CAK = "AK"
    """
    AIR AMBULANCE REQUIRED - For ambulance claims. Air ambulance required; time needed to transport poses a threat.
    """

    CAL = "AL"
    """
    SPECIALIZED TREATMENT/BED UNAVAILABLE - ALTERNATE FACILITY TRANSPORT - For ambulance claims. Specialized treatment bed unavailable. Transport to alternate facility.
    """

    CAM = "AM"
    """
    NON-EMERGENCY MEDICALLY NECESSARY STRETCHER TRANSPORT REQUIRED - For ambulance claims. Non-emergency medically necessary stretcher transport required.
    """

    CAN = "AN"
    """
    PREADMISSION SCREENING NOT REQUIRED - Person meets the criteria for an exemption from preadmission screening.
    """

    CB_0 = "B0"
    """
    MEDICARE COORDINATED CARE DEMONSTRATION CLAIM - Patient is participant in the Medicare Coordinated Care Demonstration.
    """

    CB_1 = "B1"
    """
    BENEFICIARY IS INELIGIBLE FOR DEMONSTRATION PROGRAM - Beneficiary is ineligible for demonstration program.
    """

    CB_2 = "B2"
    """
    CRITICAL ACCESS HOSPITAL AMBULANCE ATTESTATION - Attestation by Critical Access Hospital that it meets the criteria for exemption from the ambulance fee schedule.
    """

    CB_3 = "B3"
    """
    PREGNANCY INDICATOR - Indicates patient is pregnant. Required when mandated by law; determination of pregnancy completed in compliance with applicable law.
    """

    CB_4 = "B4"
    """
    ADMISSION UNRELATED TO DISCHARGE ON SAME DAY - Report code when a patient is discharged/transferred from an acute care PPS hospital on the same day for symptoms unrelated to and/or not for evaluation and management of, the prior stay’s medical condition.
    """

    CBP = "BP"
    """
    GULF OIL SPILL OF 2010 (EFFECTIVE 4/20/10) - This code identifies claims where the provision of all services on the claim are related, in whole or in part, to an illness, injury, or condition that was caused by or exacerbated by the effects, direct or indirect, of the 2010 oil spill in the Gulf of Mexico and/or circumstances related to such spill, including but not limited to subsequent clean-up activities.
    """

    CC_1 = "C1"
    """
    APPROVED AS BILLED - The services provided for this billing period have been reviewed by the QIO or intermediary, as appropriate, and are fully approved including any day or cost outlier.
    """

    CC_2 = "C2"
    """
    AUTOMATIC APPROVAL AS BILLED BASED ON FOCUSED REVIEW - This should include only categories of cases that the QIO has determined it need not review under a focused review program. (No longer used for Medicare.)
    """

    CC_3 = "C3"
    """
    PARTIAL APPROVAL - The services provided for this billing period have been reviewed by the QIO or intermediary, as appropriate, and some portion has been denied (days, or services).
    """

    CC_4 = "C4"
    """
    ADMISSION/SERVICES DENIED - This should only be used to indicate that all of the services were denied by the QIO.
    """

    CC_5 = "C5"
    """
    POST PAYMENT REVIEW APPLICABLE - This should be used indicated that the QIO review will take place after payment.
    """

    CC_6 = "C6"
    """
    ADMISSION PREAUTHORIZATION - The QIO authorized this admission/service but has not reviewed the services provided.
    """

    CC_7 = "C7"
    """
    EXTENDED AUTHORIZATION - The QIO has authorized these services for an extended length of time but has not reviewed the services provided.
    """

    CD_0 = "D0"
    """
    CHANGES TO SERVICE DATES - Changes to service dates.
    """

    CD_1 = "D1"
    """
    CHANGES TO CHARGES - Changes to charges.
    """

    CD_2 = "D2"
    """
    CHANGES IN REVENUE CODES/HCPCS/HIPPS RATE CODES - Report this claim change reason code on a replacement claim (Bill Type Frequency Code 7) to reflect a change in Revenue Codes (FL42) HCPCS/HIPPS Rate Codes (FL44).
    """

    CD_3 = "D3"
    """
    SECOND OR SUBSEQUENT INTERIM PPS BILL - Second or subsequent Interim PPS bill.
    """

    CD_4 = "D4"
    """
    CHANGE IN CLINICAL CODES (ICD) FOR DIAGNOSIS AND/OR PROCEDURE CODES - Report this claim change reason code on a replacement claim (Bill Type Frequency Code 7) to reflect a change in diagnosis (FL67) and procedure codes (FL74).
    """

    CD_5 = "D5"
    """
    CANCEL TO CORRECT INSURED’S ID OR PROVIDER ID - Cancel only to correct insured’s ID or provider identification number.
    """

    CD_6 = "D6"
    """
    CANCEL ONLY TO REPAY A DUPLICATE OR OIG OVERPAYMENT - Cancel only to repay a duplicate payment or OIG overpayment. (Includes cancellation of an
    outpatient bill containing services required to be included on the inpatient bill.)
    """

    CD_7 = "D7"
    """
    CHANGE TO MAKE MEDICARE THE SECONDARY PAYER - Change to make Medicare the secondary payer.
    """

    CD_8 = "D8"
    """
    CHANGE TO MAKE MEDICARE THE PRIMARY PAYER - Change to make Medicare the primary payer.
    """

    CD_9 = "D9"
    """
    ANY OTHER CHANGE - Any other change.
    """

    CD_RA = "DR(a)"
    """
    DISASTER RELATED - Used to identify claims that are or may be impacted by specific payer/health plan policies related to a national or regional disaster.
    """

    CE_0 = "E0"
    """
    CHANGE IN PATIENT STATUS - Change in patient status.
    """

    CG_0 = "G0"
    """
    DISTINCT MEDICAL VISIT - Report this code when multiple medical visits occurred on the same day in the same revenue center but the visits were distinct and constituted independent visits. An example of such a situation would be a beneficiary going to the emergency room twice on the same day, in the morning for a broken arm and later for chest pain.
    """

    CH_0 = "H0"
    """
    DELAYED FILING; STATEMENT OF INTENT SUBMITTED - Code indicates submission of “Statement of Intent” within the qualifying period to specifically identify the existence of another third party liability situation.
    """

    CH_2 = "H2"
    """
    DISCHARGE BY A HOSPICE PROVIDER FOR CAUSE (EFFECTIVE 1/1/09) - Discharge by a hospice provider for cause.
    """

    CH_3 = "H3"
    """
    REOCCURRENCE OF GI BLEED COMORBID CATEGORY (EFFECTIVE 1/1/11) - Code indicates a reoccurrence of GI bleed comorbid category limited for use in conjunction with ESRD PPS and applicable to 072x types of bill only.
    """

    CH_4 = "H4"
    """
    REOCCURRENCE OF PNEUMONIA COMORBID CATEGORY (EFFECTIVE 1/1/11) - Code indicates a reoccurrence of pneumonia comorbid category limited for use in conjunction with ESRD PPS and applicable to 072x types of bill only.
    """

    CH_5 = "H5"
    """
    REOCCURRENCE OF PERICARDITIS COMORBID CATEGORY (EFFECTIVE 1/1/11) - Code indicates a reoccurrence of pericarditis comorbid category limited for use in conjunction with ESRD PPS and applicable to 072x types of bill only.
    """

    CP_1 = "P1"
    """
    DO NOT RESUSCITATE ORDER (DNR) - FOR PUBLIC HEALTH DATA REPORTING ONLY when required by state or federal law or regulations. Code indicates that a DNR order was written at the time of or within the first 24 hours of the patient’s admission to the hospital and is clearly documented in the patient’s medical record.
    """

    CP_7 = "P7"
    """
    DIRECT INPATIENT ADMISSION FROM EMERGENCY ROOM (EFFECTIVE 7/1/10) - FOR PUBLIC HEALTH DATA REPORTING ONLY when required by state or federal law or regulations. Code indicates that patient was admitted directly from this facility’s Emergency Room/Department.
    """

    CR_1 = "R1"
    """
    REQUEST FOR REOPENING REASON CODE - MATHEMATICAL OR COMPUTATIONAL MISTAKES (EFFECTIVE 1/1/16) - Mathematical or computational mistakes.
    """

    CR_2 = "R2"
    """
    REQUEST FOR REOPENING REASON CODE - INACCURATE DATA ENTRY (EFFECTIVE 1/1/16) - Inaccurate data entry, e.g., miskeyed or transposed provider number, referring NPI, date of service, procedure code, etc.
    """

    CR_3 = "R3"
    """
    REQUEST FOR REOPENING REASON CODE - MISAPPLICATION OF A FEE SCHEDULE (EFFECTIVE 1/1/16) - Misapplication of a fee schedule.
    """

    CR_4 = "R4"
    """
    REQUEST FOR REOPENING REASON CODE - COMPUTER ERRORS (EFFECTIVE 1/1/16) - Computer errors.
    """

    CR_5 = "R5"
    """
    REQUEST FOR REOPENING REASON CODE - INCORRECTLY IDENTIFIED DUPLICATE CLAIM (EFFECTIVE 1/1/16) - Claims denied as duplicates which the party believes were incorrectly identified as a duplicate.
    """

    CR_6 = "R6"
    """
    REQUEST FOR REOPENING REASON CODE - OTHER CLERICAL ERRORS OR MINOR ERRORS AND OMISSIONS NOT SPECIFIED IN R1-R5 ABOVE (EFFECTIVE 1/1/16) - Other clerical errors or minor errors and omissions not specified in R1-R5 above.
    """

    CR_7 = "R7"
    """
    REQUEST FOR REOPENING REASON CODE - CORRECTIONS OTHER THAN CLERICAL ERRORS (EFFECTIVE 1/1/16) - Claim corrections other than clerical errors within one year of the date of initial determination.
    """

    CR_8 = "R8"
    """
    REQUEST FOR REOPENING REASON CODE - NEW AND MATERIAL EVIDENCE (EFFECTIVE 1/1/16) - A reopening for good cause (one to four years from the date of the initial determination) due to new and material evidence that was not available or known at the time of the determination or decision and may result in a different conclusion.
    """

    CR_9 = "R9"
    """
    REQUEST FOR REOPENING REASON CODE - FAULTY EVIDENCE (EFFECTIVE 1/1/16) - A reopening for good cause (one to four years from the date of the initial determination) because the evidence that was considered in making the determination or decision clearly shows that an obvious error was made at the time of the determination or decision.
    """

    CW_0 = "W0"
    """
    UNITED MINE WORKERS OF AMERICA (UMWA) DEMONSTRATION INDICATOR - Used for United Mine Workers of America (UMWA) demonstration indicator ONLY.
    """

    CW_2 = "W2"
    """
    DUPLICATE OF ORIGINAL BILL (EFFECTIVE 10/1/08) - Code indicates bill is exact duplicate of the original bill submitted.
    """

    CW_3 = "W3"
    """
    LEVEL I APPEAL (EFFECTIVE 10/1/08) - Code indicates bill is submitted for reconsideration; the level of appeal / reconsideration (I) is specified/defined by the payer.
    """

    CW_4 = "W4"
    """
    LEVEL II APPEAL (EFFECTIVE 10/1/08) - Code indicates bill is submitted for reconsideration; the level of appeal / reconsideration (II) is specified/defined by the payer.
    """

    CW_5 = "W5"
    """
    LEVEL III APPEAL (EFFECTIVE 10/1/08) - Code indicates bill is submitted for reconsideration; the level of appeal / reconsideration (II) is specified/defined by the payer.
    """

    _UNKNOWN = "__CONDITIONCODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ConditionCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        c_01: typing.Callable[[], T_Result],
        c_02: typing.Callable[[], T_Result],
        c_03: typing.Callable[[], T_Result],
        c_04: typing.Callable[[], T_Result],
        c_05: typing.Callable[[], T_Result],
        c_06: typing.Callable[[], T_Result],
        c_07: typing.Callable[[], T_Result],
        c_08: typing.Callable[[], T_Result],
        c_09: typing.Callable[[], T_Result],
        c_10: typing.Callable[[], T_Result],
        c_11: typing.Callable[[], T_Result],
        c_17: typing.Callable[[], T_Result],
        c_18: typing.Callable[[], T_Result],
        c_19: typing.Callable[[], T_Result],
        c_20: typing.Callable[[], T_Result],
        c_21: typing.Callable[[], T_Result],
        c_22: typing.Callable[[], T_Result],
        c_23: typing.Callable[[], T_Result],
        c_24: typing.Callable[[], T_Result],
        c_25: typing.Callable[[], T_Result],
        c_26: typing.Callable[[], T_Result],
        c_27: typing.Callable[[], T_Result],
        c_28: typing.Callable[[], T_Result],
        c_29: typing.Callable[[], T_Result],
        c_30: typing.Callable[[], T_Result],
        c_31: typing.Callable[[], T_Result],
        c_32: typing.Callable[[], T_Result],
        c_33: typing.Callable[[], T_Result],
        c_34: typing.Callable[[], T_Result],
        c_35: typing.Callable[[], T_Result],
        c_36: typing.Callable[[], T_Result],
        c_37: typing.Callable[[], T_Result],
        c_38: typing.Callable[[], T_Result],
        c_39: typing.Callable[[], T_Result],
        c_40: typing.Callable[[], T_Result],
        c_41: typing.Callable[[], T_Result],
        c_42: typing.Callable[[], T_Result],
        c_43: typing.Callable[[], T_Result],
        c_44: typing.Callable[[], T_Result],
        c_45: typing.Callable[[], T_Result],
        c_46: typing.Callable[[], T_Result],
        c_47: typing.Callable[[], T_Result],
        c_48: typing.Callable[[], T_Result],
        c_49: typing.Callable[[], T_Result],
        c_50: typing.Callable[[], T_Result],
        c_51: typing.Callable[[], T_Result],
        c_52: typing.Callable[[], T_Result],
        c_53: typing.Callable[[], T_Result],
        c_54: typing.Callable[[], T_Result],
        c_55: typing.Callable[[], T_Result],
        c_56: typing.Callable[[], T_Result],
        c_57: typing.Callable[[], T_Result],
        c_58: typing.Callable[[], T_Result],
        c_59: typing.Callable[[], T_Result],
        c_60: typing.Callable[[], T_Result],
        c_61: typing.Callable[[], T_Result],
        c_66: typing.Callable[[], T_Result],
        c_67: typing.Callable[[], T_Result],
        c_68: typing.Callable[[], T_Result],
        c_69: typing.Callable[[], T_Result],
        c_70: typing.Callable[[], T_Result],
        c_71: typing.Callable[[], T_Result],
        c_72: typing.Callable[[], T_Result],
        c_73: typing.Callable[[], T_Result],
        c_74: typing.Callable[[], T_Result],
        c_75: typing.Callable[[], T_Result],
        c_76: typing.Callable[[], T_Result],
        c_77: typing.Callable[[], T_Result],
        c_78: typing.Callable[[], T_Result],
        c_79: typing.Callable[[], T_Result],
        c_80: typing.Callable[[], T_Result],
        c_81: typing.Callable[[], T_Result],
        c_82: typing.Callable[[], T_Result],
        c_83: typing.Callable[[], T_Result],
        c_84: typing.Callable[[], T_Result],
        c_85: typing.Callable[[], T_Result],
        c_86: typing.Callable[[], T_Result],
        c_87: typing.Callable[[], T_Result],
        c_88: typing.Callable[[], T_Result],
        c_89: typing.Callable[[], T_Result],
        c_90: typing.Callable[[], T_Result],
        c_91: typing.Callable[[], T_Result],
        c_92: typing.Callable[[], T_Result],
        ca_0: typing.Callable[[], T_Result],
        ca_1: typing.Callable[[], T_Result],
        ca_2: typing.Callable[[], T_Result],
        ca_3: typing.Callable[[], T_Result],
        ca_4: typing.Callable[[], T_Result],
        ca_5: typing.Callable[[], T_Result],
        ca_6: typing.Callable[[], T_Result],
        ca_7: typing.Callable[[], T_Result],
        ca_9: typing.Callable[[], T_Result],
        caa: typing.Callable[[], T_Result],
        cab: typing.Callable[[], T_Result],
        cac: typing.Callable[[], T_Result],
        cad: typing.Callable[[], T_Result],
        cae: typing.Callable[[], T_Result],
        caf: typing.Callable[[], T_Result],
        cag: typing.Callable[[], T_Result],
        cah: typing.Callable[[], T_Result],
        cai: typing.Callable[[], T_Result],
        caj: typing.Callable[[], T_Result],
        cak: typing.Callable[[], T_Result],
        cal: typing.Callable[[], T_Result],
        cam: typing.Callable[[], T_Result],
        can: typing.Callable[[], T_Result],
        cb_0: typing.Callable[[], T_Result],
        cb_1: typing.Callable[[], T_Result],
        cb_2: typing.Callable[[], T_Result],
        cb_3: typing.Callable[[], T_Result],
        cb_4: typing.Callable[[], T_Result],
        cbp: typing.Callable[[], T_Result],
        cc_1: typing.Callable[[], T_Result],
        cc_2: typing.Callable[[], T_Result],
        cc_3: typing.Callable[[], T_Result],
        cc_4: typing.Callable[[], T_Result],
        cc_5: typing.Callable[[], T_Result],
        cc_6: typing.Callable[[], T_Result],
        cc_7: typing.Callable[[], T_Result],
        cd_0: typing.Callable[[], T_Result],
        cd_1: typing.Callable[[], T_Result],
        cd_2: typing.Callable[[], T_Result],
        cd_3: typing.Callable[[], T_Result],
        cd_4: typing.Callable[[], T_Result],
        cd_5: typing.Callable[[], T_Result],
        cd_6: typing.Callable[[], T_Result],
        cd_7: typing.Callable[[], T_Result],
        cd_8: typing.Callable[[], T_Result],
        cd_9: typing.Callable[[], T_Result],
        cd_ra: typing.Callable[[], T_Result],
        ce_0: typing.Callable[[], T_Result],
        cg_0: typing.Callable[[], T_Result],
        ch_0: typing.Callable[[], T_Result],
        ch_2: typing.Callable[[], T_Result],
        ch_3: typing.Callable[[], T_Result],
        ch_4: typing.Callable[[], T_Result],
        ch_5: typing.Callable[[], T_Result],
        cp_1: typing.Callable[[], T_Result],
        cp_7: typing.Callable[[], T_Result],
        cr_1: typing.Callable[[], T_Result],
        cr_2: typing.Callable[[], T_Result],
        cr_3: typing.Callable[[], T_Result],
        cr_4: typing.Callable[[], T_Result],
        cr_5: typing.Callable[[], T_Result],
        cr_6: typing.Callable[[], T_Result],
        cr_7: typing.Callable[[], T_Result],
        cr_8: typing.Callable[[], T_Result],
        cr_9: typing.Callable[[], T_Result],
        cw_0: typing.Callable[[], T_Result],
        cw_2: typing.Callable[[], T_Result],
        cw_3: typing.Callable[[], T_Result],
        cw_4: typing.Callable[[], T_Result],
        cw_5: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ConditionCode.C_01:
            return c_01()
        if self is ConditionCode.C_02:
            return c_02()
        if self is ConditionCode.C_03:
            return c_03()
        if self is ConditionCode.C_04:
            return c_04()
        if self is ConditionCode.C_05:
            return c_05()
        if self is ConditionCode.C_06:
            return c_06()
        if self is ConditionCode.C_07:
            return c_07()
        if self is ConditionCode.C_08:
            return c_08()
        if self is ConditionCode.C_09:
            return c_09()
        if self is ConditionCode.C_10:
            return c_10()
        if self is ConditionCode.C_11:
            return c_11()
        if self is ConditionCode.C_17:
            return c_17()
        if self is ConditionCode.C_18:
            return c_18()
        if self is ConditionCode.C_19:
            return c_19()
        if self is ConditionCode.C_20:
            return c_20()
        if self is ConditionCode.C_21:
            return c_21()
        if self is ConditionCode.C_22:
            return c_22()
        if self is ConditionCode.C_23:
            return c_23()
        if self is ConditionCode.C_24:
            return c_24()
        if self is ConditionCode.C_25:
            return c_25()
        if self is ConditionCode.C_26:
            return c_26()
        if self is ConditionCode.C_27:
            return c_27()
        if self is ConditionCode.C_28:
            return c_28()
        if self is ConditionCode.C_29:
            return c_29()
        if self is ConditionCode.C_30:
            return c_30()
        if self is ConditionCode.C_31:
            return c_31()
        if self is ConditionCode.C_32:
            return c_32()
        if self is ConditionCode.C_33:
            return c_33()
        if self is ConditionCode.C_34:
            return c_34()
        if self is ConditionCode.C_35:
            return c_35()
        if self is ConditionCode.C_36:
            return c_36()
        if self is ConditionCode.C_37:
            return c_37()
        if self is ConditionCode.C_38:
            return c_38()
        if self is ConditionCode.C_39:
            return c_39()
        if self is ConditionCode.C_40:
            return c_40()
        if self is ConditionCode.C_41:
            return c_41()
        if self is ConditionCode.C_42:
            return c_42()
        if self is ConditionCode.C_43:
            return c_43()
        if self is ConditionCode.C_44:
            return c_44()
        if self is ConditionCode.C_45:
            return c_45()
        if self is ConditionCode.C_46:
            return c_46()
        if self is ConditionCode.C_47:
            return c_47()
        if self is ConditionCode.C_48:
            return c_48()
        if self is ConditionCode.C_49:
            return c_49()
        if self is ConditionCode.C_50:
            return c_50()
        if self is ConditionCode.C_51:
            return c_51()
        if self is ConditionCode.C_52:
            return c_52()
        if self is ConditionCode.C_53:
            return c_53()
        if self is ConditionCode.C_54:
            return c_54()
        if self is ConditionCode.C_55:
            return c_55()
        if self is ConditionCode.C_56:
            return c_56()
        if self is ConditionCode.C_57:
            return c_57()
        if self is ConditionCode.C_58:
            return c_58()
        if self is ConditionCode.C_59:
            return c_59()
        if self is ConditionCode.C_60:
            return c_60()
        if self is ConditionCode.C_61:
            return c_61()
        if self is ConditionCode.C_66:
            return c_66()
        if self is ConditionCode.C_67:
            return c_67()
        if self is ConditionCode.C_68:
            return c_68()
        if self is ConditionCode.C_69:
            return c_69()
        if self is ConditionCode.C_70:
            return c_70()
        if self is ConditionCode.C_71:
            return c_71()
        if self is ConditionCode.C_72:
            return c_72()
        if self is ConditionCode.C_73:
            return c_73()
        if self is ConditionCode.C_74:
            return c_74()
        if self is ConditionCode.C_75:
            return c_75()
        if self is ConditionCode.C_76:
            return c_76()
        if self is ConditionCode.C_77:
            return c_77()
        if self is ConditionCode.C_78:
            return c_78()
        if self is ConditionCode.C_79:
            return c_79()
        if self is ConditionCode.C_80:
            return c_80()
        if self is ConditionCode.C_81:
            return c_81()
        if self is ConditionCode.C_82:
            return c_82()
        if self is ConditionCode.C_83:
            return c_83()
        if self is ConditionCode.C_84:
            return c_84()
        if self is ConditionCode.C_85:
            return c_85()
        if self is ConditionCode.C_86:
            return c_86()
        if self is ConditionCode.C_87:
            return c_87()
        if self is ConditionCode.C_88:
            return c_88()
        if self is ConditionCode.C_89:
            return c_89()
        if self is ConditionCode.C_90:
            return c_90()
        if self is ConditionCode.C_91:
            return c_91()
        if self is ConditionCode.C_92:
            return c_92()
        if self is ConditionCode.CA_0:
            return ca_0()
        if self is ConditionCode.CA_1:
            return ca_1()
        if self is ConditionCode.CA_2:
            return ca_2()
        if self is ConditionCode.CA_3:
            return ca_3()
        if self is ConditionCode.CA_4:
            return ca_4()
        if self is ConditionCode.CA_5:
            return ca_5()
        if self is ConditionCode.CA_6:
            return ca_6()
        if self is ConditionCode.CA_7:
            return ca_7()
        if self is ConditionCode.CA_9:
            return ca_9()
        if self is ConditionCode.CAA:
            return caa()
        if self is ConditionCode.CAB:
            return cab()
        if self is ConditionCode.CAC:
            return cac()
        if self is ConditionCode.CAD:
            return cad()
        if self is ConditionCode.CAE:
            return cae()
        if self is ConditionCode.CAF:
            return caf()
        if self is ConditionCode.CAG:
            return cag()
        if self is ConditionCode.CAH:
            return cah()
        if self is ConditionCode.CAI:
            return cai()
        if self is ConditionCode.CAJ:
            return caj()
        if self is ConditionCode.CAK:
            return cak()
        if self is ConditionCode.CAL:
            return cal()
        if self is ConditionCode.CAM:
            return cam()
        if self is ConditionCode.CAN:
            return can()
        if self is ConditionCode.CB_0:
            return cb_0()
        if self is ConditionCode.CB_1:
            return cb_1()
        if self is ConditionCode.CB_2:
            return cb_2()
        if self is ConditionCode.CB_3:
            return cb_3()
        if self is ConditionCode.CB_4:
            return cb_4()
        if self is ConditionCode.CBP:
            return cbp()
        if self is ConditionCode.CC_1:
            return cc_1()
        if self is ConditionCode.CC_2:
            return cc_2()
        if self is ConditionCode.CC_3:
            return cc_3()
        if self is ConditionCode.CC_4:
            return cc_4()
        if self is ConditionCode.CC_5:
            return cc_5()
        if self is ConditionCode.CC_6:
            return cc_6()
        if self is ConditionCode.CC_7:
            return cc_7()
        if self is ConditionCode.CD_0:
            return cd_0()
        if self is ConditionCode.CD_1:
            return cd_1()
        if self is ConditionCode.CD_2:
            return cd_2()
        if self is ConditionCode.CD_3:
            return cd_3()
        if self is ConditionCode.CD_4:
            return cd_4()
        if self is ConditionCode.CD_5:
            return cd_5()
        if self is ConditionCode.CD_6:
            return cd_6()
        if self is ConditionCode.CD_7:
            return cd_7()
        if self is ConditionCode.CD_8:
            return cd_8()
        if self is ConditionCode.CD_9:
            return cd_9()
        if self is ConditionCode.CD_RA:
            return cd_ra()
        if self is ConditionCode.CE_0:
            return ce_0()
        if self is ConditionCode.CG_0:
            return cg_0()
        if self is ConditionCode.CH_0:
            return ch_0()
        if self is ConditionCode.CH_2:
            return ch_2()
        if self is ConditionCode.CH_3:
            return ch_3()
        if self is ConditionCode.CH_4:
            return ch_4()
        if self is ConditionCode.CH_5:
            return ch_5()
        if self is ConditionCode.CP_1:
            return cp_1()
        if self is ConditionCode.CP_7:
            return cp_7()
        if self is ConditionCode.CR_1:
            return cr_1()
        if self is ConditionCode.CR_2:
            return cr_2()
        if self is ConditionCode.CR_3:
            return cr_3()
        if self is ConditionCode.CR_4:
            return cr_4()
        if self is ConditionCode.CR_5:
            return cr_5()
        if self is ConditionCode.CR_6:
            return cr_6()
        if self is ConditionCode.CR_7:
            return cr_7()
        if self is ConditionCode.CR_8:
            return cr_8()
        if self is ConditionCode.CR_9:
            return cr_9()
        if self is ConditionCode.CW_0:
            return cw_0()
        if self is ConditionCode.CW_2:
            return cw_2()
        if self is ConditionCode.CW_3:
            return cw_3()
        if self is ConditionCode.CW_4:
            return cw_4()
        if self is ConditionCode.CW_5:
            return cw_5()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from .raw_client import AsyncRawV1Client, RawV1Client
from .types.insurance_adjudication import InsuranceAdjudication
from .types.insurance_adjudication_id import InsuranceAdjudicationId


class V1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawV1Client
        """
        return self._raw_client

    def get(
        self,
        insurance_adjudication_id: InsuranceAdjudicationId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> InsuranceAdjudication:
        """
        Retrieves a previously created insurance adjudication by its `insurance_adjudication_id`.

        Parameters
        ----------
        insurance_adjudication_id : InsuranceAdjudicationId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        InsuranceAdjudication

        Examples
        --------
        import uuid

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.insurance_adjudications.v_1.get(
            insurance_adjudication_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._raw_client.get(insurance_adjudication_id, request_options=request_options)
        return _response.data


class AsyncV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawV1Client
        """
        return self._raw_client

    async def get(
        self,
        insurance_adjudication_id: InsuranceAdjudicationId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> InsuranceAdjudication:
        """
        Retrieves a previously created insurance adjudication by its `insurance_adjudication_id`.

        Parameters
        ----------
        insurance_adjudication_id : InsuranceAdjudicationId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        InsuranceAdjudication

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.insurance_adjudications.v_1.get(
                insurance_adjudication_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(insurance_adjudication_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....eligibility_checks.resources.v_1.types.eligibility_status import EligibilityStatus


class LatestEligibilityCheck(UniversalBaseModel):
    """
    A type to represent the latest eligibility check status of a coverage.
    """

    check_id: str
    status: EligibilityStatus
    initiated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
